pigz version 2.5
diff --git a/README b/README
index e59b3b1..c880cd5 100644
--- a/README
+++ b/README
@@ -1,4 +1,4 @@
-pigz 2.4.1x (xx Dec 2017) by Mark Adler
+pigz 2.5 (23 Jan 2021) by Mark Adler
 
 pigz, which stands for Parallel Implementation of GZip, is a fully functional
 replacement for gzip that exploits multiple processors and multiple cores to
diff --git a/pigz.1 b/pigz.1
index 400da48..b292fbd 100644
--- a/pigz.1
+++ b/pigz.1
@@ -1,4 +1,4 @@
-.TH PIGZ 1 "December 26, 2017"
+.TH PIGZ 1 "January 23, 2021"
 .SH NAME
 pigz, unpigz \- compress or expand files
 .SH SYNOPSIS
@@ -234,4 +234,4 @@
 warranty.  In no event will the author be held liable for any damages
 arising from the use of this software.
 .PP
-Copyright (C) 2007-2017 Mark Adler <madler@alumni.caltech.edu>
+Copyright (C) 2007-2021 Mark Adler <madler@alumni.caltech.edu>
diff --git a/pigz.pdf b/pigz.pdf
index 82a1b8c..ae52a17 100644
--- a/pigz.pdf
+++ b/pigz.pdf
Binary files differ
diff --git a/pigz.spec b/pigz.spec
index 7839688..955e197 100644
--- a/pigz.spec
+++ b/pigz.spec
@@ -1,6 +1,6 @@
 Summary: pigz is a parallel implementation of gzip which utilizes multiple cores
 Name: pigz
-Version: 2.4.1x
+Version: 2.5
 Release: 1
 Source0: %{name}-%{version}.tar.gz
 License: zlib
diff --git a/pigz.c b/pigz.c
index 665e5f0..e5a094a 100644
--- a/pigz.c
+++ b/pigz.c
@@ -1,6 +1,6 @@
 /* pigz.c -- parallel implementation of gzip
  * Copyright (C) 2007-2017 Mark Adler
  * Version 2.4.1x  xx Dec 2017  Mark Adler
  */
 
 /*
@@ -186,9 +186,18 @@
                        Disallow an empty suffix (e.g. --suffix '')
                        Return an exit code of 1 if any issues are encountered
                        Fix sign error in compression reduction percentage
+   2.5    23 Jan 2021  Add --alias/-A option to set .zip name for stdin input
+                       Add --comment/-C option to add comment in .gz or .zip
+                       Fix a bug that misidentified a multi-entry .zip
+                       Fix a bug that did not emit double syncs for -i -p 1
+                       Fix a bug in yarn that could try to access freed data
+                       Do not delete multi-entry .zip files when extracting
+                       Do not reject .zip entries with bit 11 set
+                       Avoid a possible threads lock-order inversion
+                       Ignore trailing junk after a gzip stream by default
  */
 
-#define VERSION "pigz 2.4.1x"
+#define VERSION "pigz 2.5"
 
 /* To-do:
     - make source portable for Windows, VMS, etc. (see gzip source code)
@@ -4415,7 +4424,7 @@
             case 'K':  g.form = 2;  g.sufx = ".zip";  break;
             case 'L':
                 puts(VERSION);
-                puts("Copyright (C) 2007-2017 Mark Adler");
+                puts("Copyright (C) 2007-2021 Mark Adler");
                 puts("Subject to the terms of the zlib license.");
                 puts("No warranty is provided or implied.");
                 exit(0);
@@ -1,6 +1,6 @@
 /* pigz.c -- parallel implementation of gzip
- * Copyright (C) 2007-2017 Mark Adler
- * Version 2.4.1x  xx Dec 2017  Mark Adler
+ * Copyright (C) 2007-2021 Mark Adler
+ * Version 2.5  23 Jan 2021  Mark Adler
  */
 